@@ -62,7 +62,7 @@ class PytificationsMessageWithPhoto:
         for row in buttons:
             rowButtons = []
             for column in row:
-                Pytifications._registered_callbacks[column.callback.__name__] = column.callback
+                Pytifications._registered_callbacks[column.callback.__name__] = {"function":column.callback,"args":self}
                 rowButtons.append({
                     "callback_name":column.callback.__name__,
                     "text":column.text
@@ -84,7 +84,7 @@ class PytificationsMessageWithPhoto:
         else:
             request_data['photo'] = image_to_byte_array(self._image)
 
-        if text != "":
+        if text != "": 
             request_data["message"] = text
         
         try:     
@@ -123,7 +123,7 @@ class PytificationsMessage:
         for row in buttons:
             rowButtons = []
             for column in row:
-                Pytifications._registered_callbacks[column.callback.__name__] = column.callback
+                Pytifications._registered_callbacks[column.callback.__name__] =  {"function":column.callback,"args":self}
                 rowButtons.append({
                     "callback_name":column.callback.__name__,
                     "text":column.text
@@ -316,7 +316,7 @@ class Pytifications:
         for row in buttons:
             rowButtons = []
             for column in row:
-                Pytifications._registered_callbacks[column.callback.__name__] = column.callback
+                Pytifications._registered_callbacks[column.callback.__name__] = {"function":column.callback,"args":self}
                 rowButtons.append({
                     "callback_name":column.callback.__name__,
                     "text":column.text
